@@ -13,7 +13,7 @@ from __future__ import absolute_import, division, unicode_literals
 from jx_base.expressions.expression import Expression
 from jx_base.expressions.false_op import FALSE
 from jx_base.language import is_op
-from mo_json import BOOLEAN
+from mo_json.types import T_BOOLEAN
 
 
 class BasicEqOp(Expression):
@@ -21,21 +21,24 @@ class BasicEqOp(Expression):
     PLACEHOLDER FOR BASIC `==` OPERATOR (CAN NOT DEAL WITH NULLS)
     """
 
-    data_type = BOOLEAN
+    _data_type = T_BOOLEAN
 
-    def __init__(self, terms):
-        Expression.__init__(self, terms)
+    def __init__(self, *terms):
+        Expression.__init__(self, *terms)
         self.lhs, self.rhs = terms
 
     def __data__(self):
         return {"basic.eq": [self.lhs.__data__(), self.rhs.__data__()]}
 
-    def missing(self):
+    def missing(self, lang):
         return FALSE
 
     def vars(self):
         return self.lhs.vars() | self.rhs.vars()
 
+    def map(self, map_):
+        return BasicEqOp(self.lhs.map(map_), self.rhs.map(map_))
+
     def __eq__(self, other):
         if not is_op(other, BasicEqOp):
             return False
