@@ -10,7 +10,7 @@
 
 from __future__ import absolute_import, division, unicode_literals
 
-from jx_base.expressions._utils import simplified, builtin_ops
+from jx_base.expressions._utils import builtin_ops
 from jx_base.expressions.and_op import AndOp
 from jx_base.expressions.base_binary_op import BaseBinaryOp
 from jx_base.expressions.eq_op import EqOp
@@ -21,25 +21,22 @@ from jx_base.expressions.or_op import OrOp
 class DivOp(BaseBinaryOp):
     op = "div"
 
-    def missing(self):
-        return self.lang[
-            AndOp(
-                [
-                    self.default.missing(),
-                    OrOp(
-                        [self.lhs.missing(), self.rhs.missing(), EqOp([self.rhs, ZERO])]
-                    ),
-                ]
-            )
-        ].partial_eval()
+    def missing(self, lang):
+        return AndOp(
+            self.default.missing(lang),
+            OrOp(
+                self.lhs.missing(lang),
+                self.rhs.missing(lang),
+                EqOp(self.rhs, ZERO),
+            ),
+        ).partial_eval(lang)
 
-    @simplified
-    def partial_eval(self):
-        default = self.default.partial_eval()
-        rhs = self.rhs.partial_eval()
+    def partial_eval(self, lang):
+        default = self.default.partial_eval(lang)
+        rhs = self.rhs.partial_eval(lang)
         if rhs is ZERO:
             return default
-        lhs = self.lhs.partial_eval()
+        lhs = self.lhs.partial_eval(lang)
         if is_literal(lhs) and is_literal(rhs):
             return Literal(builtin_ops[self.op](lhs.value, rhs.value))
         return self.__class__([lhs, rhs], default=default)
