@@ -14,39 +14,38 @@ from jx_base.expressions._utils import (
     operators,
     jx_expression,
     _jx_expression,
-    simplified
 )
-from jx_base.language import BaseExpression, ID, is_expression, is_op
-from mo_dots import is_data, is_sequence, is_container
-from mo_future import items as items_, text
+from jx_base.language import BaseExpression, ID, is_expression
+from jx_base.models.container import Container
+from mo_dots import is_data, is_container
+from mo_future import items as items_
 from mo_imports import expect
-from mo_json import BOOLEAN, OBJECT, value2json
+from mo_json import BOOLEAN, value2json, T_IS_NULL, JxType
 from mo_logs import Log
 
-TRUE, FALSE, Literal, is_literal, MissingOp, NotOp, NULL, Variable = expect(
-    "TRUE", "FALSE", "Literal", "is_literal", "MissingOp", "NotOp", "NULL", "Variable"
+TRUE, FALSE, Literal, is_literal, MissingOp, NotOp, NULL, Variable, AndOp = expect(
+    "TRUE",
+    "FALSE",
+    "Literal",
+    "is_literal",
+    "MissingOp",
+    "NotOp",
+    "NULL",
+    "Variable",
+    "AndOp",
 )
 
 
 class Expression(BaseExpression):
-    data_type = OBJECT
+    _data_type:JxType = T_IS_NULL
     has_simple_form = False
 
-    def __init__(self, args):
+    def __init__(self, *args):
         self.simplified = False
         # SOME BASIC VERIFICATION THAT THESE ARE REASONABLE PARAMETERS
-        if is_sequence(args):
-            bad = [t for t in args if t != None and not is_expression(t)]
-            if bad:
-                Log.error("Expecting an expression, not {{bad}}", bad=bad)
-        elif is_data(args):
-            if not all(is_op(k, Variable) and is_literal(v) for k, v in args.items()):
-                Log.error("Expecting an {<variable>: <literal>}")
-        elif args == None:
-            pass
-        else:
-            if not is_expression(args):
-                Log.error("Expecting an expression")
+        bad = [t for t in args if t != None and not is_expression(t)]
+        if bad:
+            Log.error("Expecting an expression, not {{bad}}", bad=bad)
 
     @classmethod
     def get_id(cls):
@@ -79,18 +78,18 @@ class Expression(BaseExpression):
                 )
 
             if term == None:
-                return class_([], **clauses)
+                return class_(**clauses)
             elif is_container(term):
                 terms = [jx_expression(t) for t in term]
-                return class_(terms, **clauses)
+                return class_(*terms, **clauses)
             elif is_data(term):
                 items = items_(term)
                 if class_.has_simple_form:
                     if len(items) == 1:
                         k, v = items[0]
-                        return class_([Variable(k), Literal(v)], **clauses)
+                        return class_(Variable(k), Literal(v), **clauses)
                     else:
-                        return class_({k: Literal(v) for k, v in items}, **clauses)
+                        Log.error("add define method to {{op}}}", op=class_.__name__)
                 else:
                     return class_(_jx_expression(term, lang), **clauses)
             else:
@@ -98,20 +97,18 @@ class Expression(BaseExpression):
                     return class_(term, **clauses)
                 else:
                     return class_(_jx_expression(term, lang), **clauses)
-        except Exception as e:
-            Log.error("programmer error expr = {{value|quote}}", value=expr, cause=e)
+        except Exception as cause:
+            Log.warning(
+                "programmer error expr = {{value|quote}}", value=expr, cause=cause
+            )
+            Log.error(
+                "programmer error expr = {{value|quote}}", value=expr, cause=cause
+            )
 
     @property
     def name(self):
         return self.__class__.__name__
 
-    @property
-    def many(self):
-        """
-        :return: True IF THE EXPRESSION RETURNS A MULTIVALUE (WHICH IS NOT A LIST OR A TUPLE)
-        """
-        return False
-
     def __data__(self):
         raise NotImplementedError
 
@@ -121,7 +118,7 @@ class Expression(BaseExpression):
     def map(self, map):
         raise Log.error("{{type}} has no `map` method", type=self.__class__.__name__)
 
-    def missing(self):
+    def missing(self, lang):
         """
         THERE IS PLENTY OF OPPORTUNITY TO SIMPLIFY missing EXPRESSIONS
         OVERRIDE THIS METHOD TO SIMPLIFY
@@ -129,7 +126,7 @@ class Expression(BaseExpression):
         """
         if self.type == BOOLEAN:
             Log.error("programmer error")
-        return self.lang[MissingOp(self)]
+        return self.lang.MissingOp(self)
 
     def exists(self):
         """
@@ -137,47 +134,77 @@ class Expression(BaseExpression):
         OVERRIDE THIS METHOD TO SIMPLIFY
         :return:
         """
-        return self.lang[NotOp(self.missing())].partial_eval()
+        return self.lang.NotOp(self.missing(self.lang)).partial_eval(self.lang)
 
-    def invert(self):
+    def invert(self, lang):
         """
         :return: TRUE IF FALSE
         """
-        inv = self.partial_eval()
-        if inv is TRUE:
+        better = self.partial_eval(lang)
+        if better is TRUE:
             return FALSE
-        elif inv is FALSE:
+        elif better is FALSE:
             return TRUE
         else:
-            return self.lang[NotOp(inv)]
+            return NotOp(better)
 
-    @simplified
-    def partial_eval(self):
+    def partial_eval(self, lang):
         """
         ATTEMPT TO SIMPLIFY THE EXPRESSION:
         PREFERABLY RETURNING A LITERAL, BUT MAYBE A SIMPLER EXPRESSION, OR self IF NOT POSSIBLE
         """
         return self
 
+    def to_jx(self, schema):
+        """
+        :param schema: THE SCHEMA USED TO INTERPRET THIS EXPRESSION
+        :return: SOMETHING BETTER
+        """
+        return self
+
+    def apply(self, container: Container, group_by):
+        """
+        Apply this expression over the container of data
+
+        q.apply(c) <=> c.query(q)
+
+        :return: data, depending on the expression
+        """
+        return container.query(self, group_by)
+
     @property
-    def type(self):
-        return self.data_type
+    def type(self) -> JxType:
+        return self._data_type
 
     def __eq__(self, other):
-        if other is None:
+        try:
+            if self.get_id() != other.get_id():
+                return False
+        except Exception:
             return False
-        if self.get_id() != other.get_id():
-            return False
-        self_class = self.__class__
-        Log.note("this is slow on {{type}}", type=text(self_class.__name__))
+        Log.note("this is slow on {{type}}", type=self.__class__.__name__)
         return self.__data__() == other.__data__()
 
+    def __contains__(self, item):
+        return item.__rcontains__(self)
+
+    def __rcontains__(self, superset):
+        """
+        :param superset: A FILTER (RETURNS BOOLEAN)
+        :return: True IF superset RETURNS True WHEN self RETURNS True
+        """
+        return self.__eq__(superset)
+
     def __str__(self):
         return value2json(self.__data__(), pretty=True)
 
+    def __repr__(self):
+        return value2json(self.__data__())
+
     def __getattr__(self, item):
         Log.error(
-            "{{type}} object has no attribute {{item}}, did you .register_ops() for {{type}}?",
+            "{{type}} object has no attribute {{item}}, did you .register_ops() for"
+            " {{type}}?",
             type=self.__class__.__name__,
             item=item,
         )
