@@ -10,7 +10,6 @@
 
 from __future__ import absolute_import, division, unicode_literals
 
-from jx_base.expressions._utils import simplified
 from jx_base.expressions.basic_substring_op import BasicSubstringOp
 from jx_base.expressions.expression import Expression
 from jx_base.expressions.length_op import LengthOp
@@ -23,15 +22,15 @@ from jx_base.expressions.variable import Variable
 from jx_base.expressions.when_op import WhenOp
 from jx_base.language import is_op
 from mo_dots import is_data
-from mo_json import STRING
+from mo_json.types import T_TEXT
 
 
 class LeftOp(Expression):
     has_simple_form = True
-    data_type = STRING
+    _data_type = T_TEXT
 
-    def __init__(self, term):
-        Expression.__init__(self, term)
+    def __init__(self, *term):
+        Expression.__init__(self, *term)
         if is_data(term):
             self.value, self.length = term.items()[0]
         else:
@@ -47,26 +46,24 @@ class LeftOp(Expression):
         return self.value.vars() | self.length.vars()
 
     def map(self, map_):
-        return self.lang[LeftOp([self.value.map(map_), self.length.map(map_)])]
+        return LeftOp(self.value.map(map_), self.length.map(map_))
 
-    def missing(self):
-        return self.lang[
-            OrOp([self.value.missing(), self.length.missing()])
-        ].partial_eval()
+    def missing(self, lang):
+        return OrOp(
+            self.value.missing(lang),
+            self.length.missing(lang),
+        ).partial_eval(lang)
 
-    @simplified
-    def partial_eval(self):
-        value = self.lang[self.value].partial_eval()
-        length = self.lang[self.length].partial_eval()
+    def partial_eval(self, lang):
+        value = (self.value).partial_eval(lang)
+        length = (self.length).partial_eval(lang)
         max_length = LengthOp(value)
 
-        return self.lang[
-            WhenOp(
-                self.missing(),
-                **{
-                    "else": BasicSubstringOp(
-                        [value, ZERO, MaxOp([ZERO, MinOp([length, max_length])])]
-                    )
-                }
-            )
-        ].partial_eval()
+        return WhenOp(
+            self.missing(lang),
+            **{"else": BasicSubstringOp(
+                value,
+                ZERO,
+                MaxOp(ZERO, MinOp(length, max_length)),
+            )}
+        ).partial_eval(lang)
