@@ -10,7 +10,6 @@
 
 from __future__ import absolute_import, division, unicode_literals
 
-from jx_base.expressions._utils import simplified
 from jx_base.expressions.expression import Expression
 from jx_base.expressions.false_op import FALSE
 from jx_base.expressions.literal import Literal
@@ -19,24 +18,25 @@ from jx_base.expressions.null_op import NULL
 from jx_base.expressions.null_op import NullOp
 from jx_base.language import is_op
 from mo_dots import is_many
-from mo_json import NUMBER
+from mo_json.types import T_NUMBER
 from mo_math import MIN
 
 
 class MinOp(Expression):
-    data_type = NUMBER
+    _data_type = T_NUMBER
 
-    def __init__(self, terms):
-        Expression.__init__(self, terms)
+    def __init__(self, *terms, default=NULL):
+        Expression.__init__(self, *terms)
         if terms == None:
             self.terms = []
         elif is_many(terms):
             self.terms = terms
         else:
             self.terms = [terms]
+        self.default = default
 
     def __data__(self):
-        return {"min": [t.__data__() for t in self.terms]}
+        return {"min": [t.__data__() for t in self.terms], "default": self.default.__data__()}
 
     def vars(self):
         output = set()
@@ -45,17 +45,16 @@ class MinOp(Expression):
         return output
 
     def map(self, map_):
-        return self.lang[MinOp([t.map(map_) for t in self.terms])]
+        return MinOp(*(t.map(map_) for t in self.terms))
 
-    def missing(self):
+    def missing(self, lang):
         return FALSE
 
-    @simplified
-    def partial_eval(self):
+    def partial_eval(self, lang):
         minimum = None
         terms = []
         for t in self.terms:
-            simple = t.partial_eval()
+            simple = t.partial_eval(lang)
             if is_op(simple, NullOp):
                 pass
             elif is_literal(simple):
@@ -69,8 +68,8 @@ class MinOp(Expression):
                 return Literal(minimum)
         else:
             if minimum == None:
-                output = self.lang[MinOp(terms)]
+                output = MinOp(terms)
             else:
-                output = self.lang[MinOp([Literal(minimum)] + terms)]
+                output = MinOp([Literal(minimum)] + terms)
 
         return output
