@@ -10,15 +10,14 @@
 
 from __future__ import absolute_import, division, unicode_literals
 
-from jx_base.expressions._utils import simplified
 from jx_base.expressions.expression import Expression
 from jx_base.language import is_op
 from mo_imports import export
-from mo_json import BOOLEAN
+from mo_json.types import T_BOOLEAN
 
 
 class NotOp(Expression):
-    data_type = BOOLEAN
+    _data_type = T_BOOLEAN
 
     def __init__(self, term):
         Expression.__init__(self, term)
@@ -27,6 +26,9 @@ class NotOp(Expression):
     def __data__(self):
         return {"not": self.term.__data__()}
 
+    def __call__(self, row, rownum=None, rows=None):
+        return not self.term(row, rownum, rows)
+
     def __eq__(self, other):
         if not is_op(other, NotOp):
             return False
@@ -36,19 +38,19 @@ class NotOp(Expression):
         return self.term.vars()
 
     def map(self, map_):
-        return self.lang[NotOp(self.term.map(map_))]
+        return NotOp(self.term.map(map_))
 
-    def missing(self):
-        return self.lang[self.term].missing()
+    def missing(self, lang):
+        return (self.term).missing(lang)
 
-    def invert(self):
-        return self.lang[self.term].partial_eval()
+    def invert(self, lang):
+        return self.term.partial_eval(lang)
 
-    @simplified
-    def partial_eval(self):
-        return self.lang[self.term].invert()
+    def partial_eval(self, lang):
+        return self.term.invert(lang)
 
 
 export("jx_base.expressions.and_op", NotOp)
+export("jx_base.expressions.basic_in_op", NotOp)
 export("jx_base.expressions.exists_op", NotOp)
 export("jx_base.expressions.expression", NotOp)
