@@ -12,7 +12,6 @@ from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions.expression import Expression
 from mo_future import is_text
-from mo_json import OBJECT
 from mo_logs import Log
 
 
@@ -21,22 +20,23 @@ class ScriptOp(Expression):
     ONLY FOR WHEN YOU TRUST THE SCRIPT SOURCE
     """
 
-    def __init__(self, script, data_type=OBJECT):
+    def __init__(self, *script, data_type):
         Expression.__init__(self, None)
         if not is_text(script):
             Log.error("expecting text of a script")
         self.simplified = True
         self.script = script
-        self.data_type = data_type
+        self._data_type = data_type
 
     @classmethod
     def define(cls, expr):
         if ALLOW_SCRIPTING:
             Log.warning(
-                "Scripting has been activated:  This has known security holes!!\nscript = {{script|quote}}",
+                "Scripting has been activated:  This has known security holes!!\nscript"
+                " = {{script|quote}}",
                 script=expr.script.term,
             )
-            return cls.lang[ScriptOp(expr.script)]
+            return ScriptOp(expr.script)
         else:
             Log.error("scripting is disabled")
 
