@@ -12,8 +12,8 @@ from __future__ import absolute_import, division, unicode_literals
 
 import re
 
-from jx_base.expressions._utils import simplified
-from jx_base.expressions.and_op import AndOp
+from jx_base.expressions._utils import TYPE_CHECK, jx_expression
+from jx_base.expressions.case_op import CaseOp
 from jx_base.expressions.expression import Expression
 from jx_base.expressions.false_op import FALSE
 from jx_base.expressions.literal import Literal, is_literal
@@ -22,23 +22,40 @@ from jx_base.expressions.true_op import TRUE
 from jx_base.expressions.variable import Variable
 from jx_base.expressions.when_op import WhenOp
 from jx_base.language import is_op
-from mo_dots import is_data
-from mo_json import BOOLEAN, STRING
+from mo_dots import coalesce
+from mo_dots import is_data, is_missing
+from mo_future import first
+from mo_json.types import T_BOOLEAN, STRING
 from mo_logs import Log
 
 
 class SuffixOp(Expression):
     has_simple_form = True
-    data_type = BOOLEAN
+    _data_type = T_BOOLEAN
 
-    def __init__(self, term):
-        Expression.__init__(self, term)
-        if not term:
-            self.expr = self.suffix = None
-        elif is_data(term):
-            self.expr, self.suffix = term.items()[0]
+    def __init__(self, expr, suffix):
+        Expression.__init__(self, expr, suffix)
+        self.expr = expr
+        self.suffix = suffix
+
+    @classmethod
+    def define(cls, expr):
+        op, param = first(expr.items())
+        if TYPE_CHECK:
+            if op not in ["suffix", "postfix"]:
+                Log.error("expecting prefix or postfix")
+        if not param:
+            return TRUE
+        elif is_data(param):
+            kv_pair = first(param.items())
+            if kv_pair:
+                expr, const = first(param.items())
+                return SuffixOp(Variable(expr), Literal(const))
+            else:
+                return TRUE
         else:
-            self.expr, self.suffix = term
+            expr, const = param
+            return SuffixOp(jx_expression(expr), jx_expression(const))
 
     def __data__(self):
         if self.expr is None:
@@ -48,7 +65,16 @@ class SuffixOp(Expression):
         else:
             return {"suffix": [self.expr.__data__(), self.suffix.__data__()]}
 
-    def missing(self):
+    def __call__(self, row, rownum=None, rows=None):
+        expr = self.expr(row, rownum, rows)
+        if is_missing(expr):
+            return None
+        suffix = self.suffix(row, rownum, rows)
+        if is_missing(suffix):
+            return None
+        return expr.endswith(suffix)
+
+    def missing(self, lang):
         """
         THERE IS PLENTY OF OPPORTUNITY TO SIMPLIFY missing EXPRESSIONS
         OVERRIDE THIS METHOD TO SIMPLIFY
@@ -65,21 +91,19 @@ class SuffixOp(Expression):
         if self.expr is None:
             return TRUE
         else:
-            return self.lang[SuffixOp([self.expr.map(map_), self.suffix.map(map_)])]
+            return SuffixOp(self.expr.map(map_), self.suffix.map(map_))
 
-    @simplified
-    def partial_eval(self):
+    def partial_eval(self, lang):
         if self.expr is None:
             return TRUE
         if not is_literal(self.suffix) and self.suffix.type == STRING:
             Log.error("can only hanlde literal suffix ")
 
-        return WhenOp(
-            self.lang[AndOp([self.expr.exists(), self.suffix.exists()])],
-            **{
-                "then": self.lang[
-                    RegExpOp([self.expr, Literal(".*" + re.escape(self.suffix.value))])
-                ],
-                "else": FALSE,
-            }
-        ).partial_eval()
+        return CaseOp(
+            WhenOp(self.expr.missing(lang), then=FALSE),
+            WhenOp(self.suffix.missing(lang), then=TRUE),
+            RegExpOp(
+                self.expr,
+                Literal(".*" + re.escape(coalesce(self.suffix.value, ""))),
+            ),
+        ).partial_eval(lang)
