@@ -10,18 +10,17 @@
 from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions import CaseOp as CaseOp_
-from jx_python.expressions._utils import Python
 
 
 class CaseOp(CaseOp_):
-    def to_python(self, not_null=False, boolean=False, many=False):
-        acc = Python[self.whens[-1]].to_python()
+    def to_python(self):
+        acc = (self.whens[-1]).to_python()
         for w in reversed(self.whens[0:-1]):
             acc = (
                 "("
-                + Python[w.then].to_python()
+                + w.then.to_python()
                 + ") if ("
-                + Python[w.when].to_python(boolean=True)
+                + w.when.to_python()
                 + ") else ("
                 + acc
                 + ")"
