@@ -10,11 +10,8 @@
 from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions import CoalesceOp as CoalesceOp_
-from jx_python.expressions._utils import Python
 
 
 class CoalesceOp(CoalesceOp_):
-    def to_python(self, not_null=False, boolean=False, many=False):
-        return (
-            "coalesce(" + (", ".join(Python[t].to_python() for t in self.terms)) + ")"
-        )
+    def to_python(self):
+        return "coalesce(" + ", ".join((t).to_python() for t in self.terms) + ")"
