@@ -10,10 +10,9 @@
 from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions import LastOp as LastOp_
-from jx_python.expressions._utils import Python
 
 
 class LastOp(LastOp_):
-    def to_python(self, not_null=False, boolean=False, many=False):
-        term = Python[self.term].to_python()
+    def to_python(self):
+        term = self.term.to_python()
         return "last(" + term + ")"
