@@ -10,9 +10,8 @@
 from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions import LeavesOp as LeavesOp_
-from jx_python.expressions._utils import Python
 
 
 class LeavesOp(LeavesOp_):
-    def to_python(self, not_null=False, boolean=False, many=False):
-        return "Data(" + Python[self.term].to_python() + ").leaves()"
+    def to_python(self):
+        return "Data(" + self.term.to_python() + ").leaves()"
