@@ -10,15 +10,14 @@
 from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions import PrefixOp as PrefixOp_
-from jx_python.expressions._utils import Python
 
 
 class PrefixOp(PrefixOp_):
-    def to_python(self, not_null=False, boolean=False, many=False):
+    def to_python(self):
         return (
             "("
-            + Python[self.expr].to_python()
+            + self.expr.to_python()
             + ").startswith("
-            + Python[self.prefix].to_python()
+            + (self.prefix).to_python()
             + ")"
         )
