@@ -10,12 +10,14 @@
 from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions import RightOp as RightOp_
-from jx_python.expressions._utils import Python, with_var
+from jx_python.expressions._utils import with_var
 
 
 class RightOp(RightOp_):
-    def to_python(self, not_null=False, boolean=False, many=False):
-        v = Python[self.value].to_python()
-        l = Python[self.length].to_python()
+    def to_python(self):
+        v = (self.value).to_python()
+        l = (self.length).to_python()
 
-        return with_var("v", v, "None if v == None else v[max(0, len(v)-int(" + l + ")):]")
+        return with_var(
+            "v", v, "None if v == None else v[max(0, len(v)-int(" + l + ")):]"
+        )
