@@ -13,6 +13,5 @@ from jx_base.expressions import TrueOp as TrueOp_
 
 
 class TrueOp(TrueOp_):
-    def to_python(self, not_null=False, boolean=False, many=False):
+    def to_python(self):
         return "True"
-
